@@ -38,7 +38,7 @@ no warnings;
 
 our @EXPORT = qw( newretrieve newreport get_files );
 
-$VERSION = '0.105';
+$VERSION = '0.109';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -200,7 +200,45 @@ sub newretrieve
       {
         my ( $result, $resfile, $shortresfile, $thisto, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile ) = @_;
 
-        my $printthis =
+#        my $printthis =
+#"cd $thisto/cfg
+#res -file $resfile -mode script<<YYY
+#
+#3
+#$retrdata[0]
+#$retrdata[1]
+#$retrdata[2]
+#c
+#g
+#a
+#a
+#-
+#b
+#a
+#-
+#b
+#e
+#-
+#b
+#f
+#-
+#>
+#$retfile
+#$retfile
+#!
+#-
+#-
+#-
+#-
+#-
+#-
+#-
+#-
+#YYY
+#";
+
+
+my $printthis =
 "cd $thisto/cfg
 res -file $resfile -mode script<<YYY
 
@@ -210,16 +248,12 @@ $retrdata[1]
 $retrdata[2]
 c
 g
-a
-a
-b
-a
 b
 e
-b
-f
+-
 >
 $retfile
+$retfile
 !
 -
 -
@@ -231,12 +265,30 @@ $retfile
 -
 YYY
 ";
+
         if ( ( $exeonfiles eq "y" ) or ( $dowhat{newretrieve} eq "y" ) )
         {
           say $tee "#Retrieving temperature results.";
           print `$printthis`;
           say $tee "$printthis";
         }
+        
+        my $olddest =  "$retfile" . ".old";
+        `mv -f $retfile $olddest`;
+        
+        open (OLDDEST, "$olddest" ) or die;
+        my @oldlines = <OLDDEST>;
+        close OLDDEST;
+        
+        open(NEWDEST, ">$retfile") or die;
+        
+        foreach my $line ( @oldlines )
+        {
+          chomp $line;
+          print NEWDEST "$line,";
+        }
+        close NEWDEST;
+     
         #print $tee "
 #Retrieving results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", simulation period $counttheme, retrieve period $countreport\n $printthis";
 
@@ -1023,12 +1075,14 @@ sub newreport # This function retrieves the results of interest from the texts f
       foreach my $line ( @lines )
       {
         chomp $line;
+        $line =~ s/^(\s+)//;
+        $line =~ s/^ +//;
         
-        if ( $line =~ /$hpattern/ )
+        ###if ( $line =~ /$hpattern/ ) ###CHANGED
+        if ( $line =~ /^$hpattern/ )
         { #say $tee "CHECK LINE-$line";
           chomp $line; 
-	  $line =~ s/^(\s+)//;
-          $line =~ s/^ +//;
+	  
           $line =~ s/:\s/:/g;
           $line =~ s/(\s+)/ /g;
           $line =~ s/ /,/g; #say $tee "CHECK TREATEDLINE-$line";
@@ -1117,11 +1171,13 @@ sub newreport # This function retrieves the results of interest from the texts f
               if ( $dowhat{simplifiedreport} eq "y" )
               {
                 my $thisline = $line;
+                $thisline =~ s/^(\s+)//;
+                $thisline =~ s/^ +)//;
 
-                if ( $thisline =~ /$textpattern/ )
+                if ( $thisline =~ /^$textpattern/ )
                 {
 	          chomp $thisline;
-                  $thisline =~ s/^(\s+)//;
+                  
                   $thisline =~ s/:\s/:/g;
                   $thisline =~ s/(\s+)/ /g;
                   $thisline =~ s/ /,/g;
